@@ -15,7 +15,7 @@ use ObjectDB::Table;
 use ObjectDB::With;
 use ObjectDB::Util qw(execute merge_rows filter_columns);
 
-our $VERSION = '3.17';
+our $VERSION = '3.18';
 
 $Carp::Internal{(__PACKAGE__)}++;
 $Carp::Internal{"ObjectDB::$_"}++ for qw/
@@ -91,11 +91,13 @@ sub init_db {
     my $dbh;
     if (@_) {
         if (@_ == 1 && ref $_[0]) {
-            $dbh = ${"$class\::DBH"} = shift;
+            ${"$class\::DBH"} = shift;
         }
         else {
-            $dbh = ${"$class\::DBH"} = ObjectDB::DBHPool->new(@_);
+            ${"$class\::DBH"} = ObjectDB::DBHPool->new(@_);
         }
+
+        $dbh = ${"$class\::DBH"};
     }
     else {
         $dbh = ${"$class\::DBH"};
